package com.steerinfo.dil.controller;

import com.alibaba.fastjson.JSON;
import com.github.pagehelper.PageHelper;
import com.steerinfo.dil.feign.ESFeign;
import com.steerinfo.dil.service.impl.BmstruckDetailsOrderServiceImpl;
import com.steerinfo.dil.util.BaseRESTfulController;
import com.steerinfo.dil.util.ColumnDataUtil;
import com.steerinfo.dil.util.PageListAdd;
import com.steerinfo.framework.controller.RESTfulResult;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiModelProperty;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.math.BigDecimal;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @Description:
 * @Author:HuJianGuo
 * @GreateTime:2021/9/24 17:29
 * @Version:V2.0
 */
@RestController
@RequestMapping("/${api.version}/bmstruckdetailsorder")
public class BmstruckDetailsOrderController extends BaseRESTfulController {

    @Autowired
    BmstruckDetailsOrderServiceImpl bmstruckDetailsOrderService;
    @Autowired
    ColumnDataUtil columnDataUtil;
    @Autowired
    ESFeign esFeign;

    /**
     * 展示汽运详单信息
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @ApiModelProperty(value = "展示汽运详单信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "销售：176/采购：140", required = false, dataType = "BigDecimal"),
            @ApiImplicitParam(name = "orderType", value = "1:销售,3:采购", required = false, dataType = "Integer")
    })
    @PostMapping("/getTruckDetailsOrderList")
    public RESTfulResult getTruckDetailsOrderList(@RequestBody(required = false) Map<String, Object> mapValue,
                                                  Integer pageNum,
                                                  Integer pageSize,
                                                  Integer apiId,
                                                  Integer orderType,
                                                  String con) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        mapValue.put("orderType",orderType);
        if (con != null) {
            if (!"undefined".equals(con)) {
                //设置要查询的索引名称
                String index = "get_truck_details_list";
                //获取查询结果
                return success(esFeign.getConResult(mapValue, index, apiId, pageNum, pageSize, con));
            }
        }
        //初始化过滤
        List<Map<String, Object>> truckDetailList = null;
        //如果有条件查询则跳过初始化，和创建索引
        if (mapValue.size() == 1) {
            //将查询结果存入索引中
            truckDetailList = bmstruckDetailsOrderService.getTruckDetailsOrderList(mapValue);
            Map<String, Object> map = new HashMap<>();
            //添加索引
            map.put("index", "get_truck_details_list");
            //添加id
            map.put("indexId", "detailsId");
            truckDetailList.add(map);
            //新建索引
            String s = JSON.toJSONString(truckDetailList);
            esFeign.insertIndex(truckDetailList);
            //删除
            truckDetailList.remove(truckDetailList.size() - 1);
        }
        if (truckDetailList == null) {
            truckDetailList = bmstruckDetailsOrderService.getTruckDetailsOrderList(mapValue);
        }
        PageHelper.startPage(pageNum, pageSize);
        //分页查询数据
        List<Map<String, Object>> columnList = bmstruckDetailsOrderService.getTruckDetailsOrderList(mapValue);
        PageListAdd data = columnDataUtil.tableColumnData(apiId, truckDetailList, columnList);
        return success(data);
    }

    /**
     * 展示汽运未生成账单的详单信息
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @ApiModelProperty(value = "展示汽运未生成账单的详单信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "销售：176", required = false, dataType = "BigDecimal"),
            @ApiImplicitParam(name = "orderType", value = "1:销售", required = false, dataType = "Integer")
    })
    @PostMapping("/getUnFinishedTruckDetailsOrderList")
    public RESTfulResult getUnFinishedTruckDetailsOrderList(@RequestBody(required = false) Map<String, Object> mapValue,
                                                            Integer pageNum,
                                                            Integer pageSize,
                                                            Integer apiId,
                                                            Integer orderType,
                                                            String con) {
        if (con != null) {
            if (!"undefined".equals(con)) {
                //设置要查询的索引名称
                String index = "get_unfinished_details_list";
                //获取查询结果
                return success(esFeign.getConResult(mapValue, index, apiId, pageNum, pageSize, con));
            }
        }
        //初始化过滤
        List<Map<String, Object>> truckDetailList = null;
        //如果有条件查询则跳过初始化，和创建索引
        if (mapValue.size() == 0) {
            //将查询结果存入索引中
            truckDetailList = bmstruckDetailsOrderService.getUnFinishedTruckDetailsOrderList(mapValue, orderType);
            Map<String, Object> map = new HashMap<>();
            //添加索引
            map.put("index", "get_unfinished_details_list");
            //添加id
            map.put("indexId", "detailsId");
            truckDetailList.add(map);
            //新建索引
            String s = JSON.toJSONString(truckDetailList);
            esFeign.insertIndex(truckDetailList);
            //删除
            truckDetailList.remove(truckDetailList.size() - 1);
        }
        if (truckDetailList == null) {
            truckDetailList = bmstruckDetailsOrderService.getUnFinishedTruckDetailsOrderList(mapValue, orderType);
        }
        PageHelper.startPage(pageNum, pageSize);
        //分页查询数据
        List<Map<String, Object>> columnList = bmstruckDetailsOrderService.getUnFinishedTruckDetailsOrderList(mapValue, orderType);
        PageListAdd data = columnDataUtil.tableColumnData(apiId, truckDetailList, columnList);
        return success(data);
    }

    /**
     * 展示汽运实绩信息
     *
     * @param mapVal
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @ApiModelProperty(value = "展示汽运实绩信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "销售：177/采购：142", required = false, dataType = "BigDecimal")
    })
    @PostMapping("/getTruckResultList")
    public RESTfulResult getTruckResultList(@RequestBody(required = false) Map<String, Object> mapVal,
                                            Integer pageNum,
                                            Integer pageSize,
                                            Integer apiId,
                                            BigDecimal orderId) {
        if (mapVal == null) {
            mapVal = new HashMap<>();
        }
        mapVal.put("orderId", orderId);
        List<Map<String, Object>> list = bmstruckDetailsOrderService.getTruckResultList(mapVal);
        PageHelper.startPage(pageNum, pageSize);
        //分页查询数据
        List<Map<String, Object>> columnList = bmstruckDetailsOrderService.getTruckResultList(mapVal);
        PageListAdd data = columnDataUtil.tableColumnData(apiId, list, columnList);
        return success(data);
    }

    /**
     * 新增详单
     *
     * @param orderId
     * @return
     */
    @ApiModelProperty(value = "新增详单")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "orderId", value = "汽运运单id", required = false, dataType = "BigDecimal"),
    })
    @PostMapping("/addDetailsOrder/{orderId}")
    public RESTfulResult addDetailsOrder(@PathVariable("orderId") BigDecimal orderId) throws Exception {
        int code = bmstruckDetailsOrderService.insertSelective(orderId);
        return success(code);
    }


}
